require 'crowd_fund/project'

module CrowdFund
  describe Project do
    before do
      @funding = 1000
      @project = Project.new("Project ABC", 5000, @funding)
      $stdout = StringIO.new
    end


  it "has an inital target funding amount" do
    expect(@project.target).to eq(5000)
  end

  it "computes the total funding outstanding as the target funding amount minus the funding amount" do
    expect(@project.total_funding_outstanding).to eq(5000 - @funding)
  end

  it "increases funds by 25 when funds are added" do
    @project.add_funds

    expect(@project.funding).to eq(@funding + 25)
  end

  it "decreases funds by 15 when funds are removed" do
    @project.remove_funds

    expect(@project.funding).to eq(@funding - 15)
  end

  context "created without a funding amount" do
      before do
        @project = Project.new("Project ABC", 5000)
      end

    it "has a default funding amount of 0" do
      @project.funding

      expect(@project.funding).to eq(0)
    end
  end

  context "when total funding outstanding is less than or equal to 0" do
    before do
      @project = Project.new("Project ABC", 5000 , 5000)
    end

    it "is fully funded" do
      expect(@project).to be_fully_funded
    end
  end

  context "when total funding outstanding is greater than 0" do
    before do
      @project = Project.new("Project ABC", 5000, 1000)
    end

      it "is under-funded" do
        expect(@project).not_to be_fully_funded
      end

      it "computes pledges as the sum of all pledges" do
        expect(@project.pledges).to eq(0)

        @project.found_pledge(Pledge.new(:silver, 75))

        expect(@project.pledges).to eq(75)

        @project.found_pledge(Pledge.new(:gold, 100))

        expect(@project.pledges).to eq(175)

        @project.found_pledge(Pledge.new(:gold, 100))

        expect(@project.pledges).to eq(275)
      end
  end

      it "computes total funds as the sum of a projects funding and pledges" do
        @project.found_pledge(Pledge.new(:gold, 100))
        @project.found_pledge(Pledge.new(:gold, 100))

        expect(@project.total_funds).to eq(1200)
      end
  end
end
